@@ -80,6 +80,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ### Amazon DynamoDB Table
 
@@ -87,6 +88,7 @@ Out of the box implementation of the Construct without any override will set the
 * Enable server-side encryption for DynamoDB Table using AWS managed KMS Key
 * Creates a partition key called 'id' for DynamoDB Table
 * Retain the Table when deleting the CloudFormation stack
+* Enable continuous backups and point-in-time recovery
 
 ## Architecture
 
@@ -104,8 +106,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -122,13 +124,13 @@ class LambdaToDynamoDB(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        table_permissions: typing.Optional[str] = None,
+        table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -156,12 +158,12 @@ class LambdaToDynamoDB(
 
         jsii.create(LambdaToDynamoDB, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
         return jsii.get(self, "dynamoTable")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
@@ -186,7 +188,7 @@ class LambdaToDynamoDBProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        table_permissions: typing.Optional[str] = None,
+        table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
@@ -201,10 +203,8 @@ class LambdaToDynamoDBProps:
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
-        self._values = {}
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        self._values: typing.Dict[str, typing.Any] = {}
         if dynamo_table_props is not None:
             self._values["dynamo_table_props"] = dynamo_table_props
         if existing_lambda_obj is not None:
@@ -223,7 +223,8 @@ class LambdaToDynamoDBProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dynamo_table_props")
+        result = self._values.get("dynamo_table_props")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -232,7 +233,8 @@ class LambdaToDynamoDBProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -241,7 +243,8 @@ class LambdaToDynamoDBProps:
         default
         :default: - None
         """
-        return self._values.get("existing_table_obj")
+        result = self._values.get("existing_table_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -252,10 +255,11 @@ class LambdaToDynamoDBProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
     @builtins.property
-    def table_permissions(self) -> typing.Optional[str]:
+    def table_permissions(self) -> typing.Optional[builtins.str]:
         """Optional table permissions to grant to the Lambda function.
 
         One of the following may be specified: "All", "Read", "ReadWrite", "Write".
@@ -263,12 +267,13 @@ class LambdaToDynamoDBProps:
         default
         :default: - Read/write access is given to the Lambda function if no value is specified.
         """
-        return self._values.get("table_permissions")
+        result = self._values.get("table_permissions")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
